function MAIN_FIGAS

% Date: 10-10-2024
% This function simulate from a multivariate FIGAS model and estimate back its
% parameteres by Maximum Likelihood

% Anne Opschoor, André Lucas, Fractional Integration and Fat Tails for Realized Covariance Kernels,
% Journal of Financial Econometrics, Volume 17, Issue 1, Winter 2019, Pages 66–90
% https://doi.org/10.1093/jjfinec/nby029
% Email: a.opschoor@vu.nl

% set stage for numerical optimization
options = optimset('fmincon');
options = optimset(options, 'Display', 'off');
options = optimset(options, 'Diagnostics', 'off');
options = optimset(options, 'Algorithm', 'sqp');

% set seed
rng(10);

% define the class with all admin utils, DGP and filters
import Admin.*
import DGP.*
import Filter.*

% basic configuration for DGP
T = 1500;
k = 5;
theta_sim = [-0.10 50 35 0.6];
V0 =wishrnd(eye(k),10);

% starting values and bounds
params  = [0.05 25 25 0.2]';
Lb = [ -10 k+1+0.01 k+1+0.01 -0.99]';
Rb = [ 0.99999 1000 1000 0.99]';

% simulate a time series path of realized covariance matrices and
[RC_sim,V_sim] = DGP.get_FIGAS_MV_F_LM( k,T, theta_sim,V0);

% estimate parameters by maximum likelihood
f_FIGAS_F_LM = @(params)Loglike_MV.LogLik_FIGAS_F_LM(k,T, params,RC_sim);
[theta_hat, minLogL,Flag] = fmincon(f_FIGAS_F_LM, params,[],[],[],[],Lb,Rb,[],options);

% get fitted values and make some plots
[V_hat,~,Flag]  = Filter.FIGAS_F_LM_tar(k, T, theta_hat,RC_sim);

subplot(2,2,1)
plot([squeeze(V_sim(1,1,:)) squeeze(V_hat(1,1,:))])
title('Simulated and fitted variance')
legend('Simulated','Fitted')

subplot(2,2,2)
plot([squeeze(V_sim(1,3,:)) squeeze(V_hat(1,3,:))])
title('Simulated and fitted covariance')
legend('Simulated','Fitted')

% compute se, and make table with true and estimated parameters plus s.e.
H = hessian_2sided(f_FIGAS_F_LM,theta_hat);
se_vec= sqrt(diag(inv(H)));
theta_name = {'B','nu1','nu2','d'};
fprintf('Estimated parameters of the FIGAS model \n');
fprintf(' \n');
fprintf(' Para    True   Est    s.e. \n');
nr_para = length(theta_sim);
for p = 1:nr_para
    fprintf(' %4s    %3.2f  %3.2f  %1.3f \n',theta_name{p},theta_sim(p),theta_hat(p), se_vec(p));
end
fprintf(' \n');
fprintf('Maximized LogLikelihood: %8.1f \n', -minLogL)





